#!/usr/bin/python
# -*- coding: utf-8 -*-
import sys
import time
import struct

import SiTCP


##########################################################
def main(argv):
	
	try:
		sitcp = SiTCP.UDP('192.168.10.128')		# RBCP open
		tcp = SiTCP.TCP(0.1, '192.168.10.128')	# TCP/IP connect

		configure_device(sitcp)
		acquire_data(sitcp, tcp, 3.0)	# data acquisition for 3.0 seconds

		sitcp.close()	# RBCP close
		tcp.close()		# TCP/IP disconnect
	except Exception as ex:
		print (ex)


##########################################################
def acquire_data(sitcp, tcp, acq_sec):

	tcp.settimeout(0.01)		# tcp recv timeout: 0.01sec(10ms)
	rlt_sec = -1.0

	# open save file
	binfile = open('./list.bin', 'wb')

	# start acquisition
	sitcp.write2byte(0xb4000014, 0)
	sitcp.write2byte(0xb4000014, 1)

	_last_sec = time.time()
	# acquisition loop
	while acq_sec > rlt_sec:
		# display status every 200msec
		if (time.time() - _last_sec) >= 0.2:
			# read status
			icr = sitcp.read4byte(0xb400022c)	# input count rate of CH1
			tcr = sitcp.read4byte(0xb4000230)	# throughput count rate of CH1
			rlt = sitcp.read6byte(0xb400001c)	# real time

			# convert real time(digits to seconds)
			rlt_sec = float(rlt) / 100000000.0

			print ("[%.3f/%.3f], input count rate = %d, throughput count rate = %d." % (rlt_sec, acq_sec, icr, tcr))
			_last_sec = time.time()
		
		# read list data
		rxdata, rxbytes = tcp.read(100000)	# max 10,000 events
		binfile.write(rxdata)

	# stop acquisition
	sitcp.write2byte(0xb4000014, 0)

	# close save file
	binfile.close()
	
	return


##########################################################
def configure_device(sitcp):

	# CH register: CH1 only
	sitcp.write2byte(0xb4000200, 1)		# analog coarse gain: x5
	sitcp.write2byte(0xb4000202, 1)		# ADC gain: 4096 bins
	sitcp.write2byte(0xb4000208, 80)	# slow rise time: 800nsec(10ns/digit)
	sitcp.write2byte(0xb400020a, 100)	# slow peaking time: 1usec(10ns/digit)
	sitcp.write2byte(0xb4000210, 50)	# fast threshold: 50ch
	sitcp.write2byte(0xb4000216, 40)	# slow threshold: 40ch
	sitcp.write2byte(0xb400021a, 1)		# polarity: negative
	sitcp.write2byte(0xb400023a, 3)		# digital coarse gain: x8
	sitcp.write2byte(0xb400023c, 4095)	# digital fine gain: x0.5 (0.5 * 8103 - 2 -> 4095)
	sitcp.write2byte(0xb4000256, 0)		# analog pole zero: 0ch
	sitcp.write2byte(0xb4000258, 200)	# analog fine gain: x1.176471
	sitcp.write2byte(0xb400020c, 0)		# fast pole zero: 0ch
	sitcp.write2byte(0xb400020e, 65)	# slow pole zero: 65ch

	# global register
	sitcp.write2byte(0xb400007a, 2)			# DAC monitor: CH1-slow
	sitcp.write2byte(0xb4000010, 1)			# mode: list
	sitcp.write6byte(0xb4000016, 300000000)	# measurement time: 3sec(10ns/digit)

	# filter reset
	sitcp.write2byte(0xb4000238, 0)
	sitcp.write2byte(0xb4000238, 1)
	sitcp.write2byte(0xb4000238, 0)

	# clear
	sitcp.write2byte(0xb4000040, 0)
	sitcp.write2byte(0xb4000040, 1)
	sitcp.write2byte(0xb4000040, 0)
	time.sleep(0.2)		# wait

	return


##########################################################
if __name__=='__main__':
	main(sys.argv)

